@@ -83,6 +83,12 @@
 #' \code{\link{sensi_plot}}
 #' @references 
 #' 
+#' Paterno, G. B., Penone, C. Werner, G. D. A. 
+#' \href{http://doi.wiley.com/10.1111/2041-210X.12990}{sensiPhy: 
+#' An r-package for sensitivity analysis in phylogenetic 
+#' comparative methods.} Methods in Ecology and Evolution 
+#' 2018, 9(6):1461-1467
+#'
 #' Werner, G.D.A., Cornwell, W.K., Sprent, J.I., Kattge, J. & Kiers, E.T. (2014).
 #' A single evolutionary innovation drives the deep evolution of symbiotic N2-fixation
 #' in angiosperms. Nature Communications, 5, 4087.
@@ -111,118 +117,182 @@
 #' @export
 
 
-intra_samp_phylm <- function(formula, data, phy, n.sim=10, n.intra = 3,
-                             breaks=seq(.1,.5,.1),model="lambda",
-                             Vy = NULL, Vx = NULL, distrib = "normal",
-                             y.transf = NULL, x.transf = NULL, track=TRUE,...) { 
-  
-  #Error check
-  if(is.null(Vx) & is.null(Vy)) stop("Vx or Vy must be defined")
-  if(class(formula) != "formula") stop("formula must be class 'formula'")
-  if(class(data) != "data.frame") stop("data must be class 'data.frame'")
-  if(class(phy) != "phylo") stop("phy must be class 'phylo'")
-  if(formula[[2]]!=all.vars(formula)[1] || formula[[3]]!=all.vars(formula)[2])
-    stop("Please use arguments y.transf or x.transf for data transformation")
-  if(distrib == "normal") warning ("distrib=normal: make sure that standard deviation is provided for Vx and/or Vy")
-  if(length(breaks) < 2) stop("Please include more than one break, e.g. breaks=c(.3,.5)")
-  if((model == "trend") && (sum(is.ultrametric(phy))>1)) 
-    stop("Trend is unidentifiable for ultrametric trees., see ?phylolm for details")
-  else
-
-
-  #Matching tree and phylogeny using utils.R
-  datphy <- match_dataphy(formula, data, phy,...)
-  full.data <- datphy[[1]]
-  phy <- datphy[[2]]
-  
-  resp <- all.vars(formula)[1]
-  pred <- all.vars(formula)[2]
-  
-  if(!is.null(Vy) && sum(is.na(full.data[, Vy])) != 0) {
-    full.data[is.na(full.data[, Vy]), Vy] <- 0}
-  
-  if(!is.null(Vx) && sum(is.na(full.data[, Vx])) != 0) {
-    full.data[is.na(full.data[, Vx]), Vx] <- 0}
-  
-  #Function to pick a random value in the interval
-  if (distrib == "normal") funr <- function(a,b) {stats::rnorm(1,a,b)}
-  else  funr <- function(a,b) {stats::runif(1, a - b, a + b)}
-  
-  #List to store information
-  intra.samp <- list()
-  species.NA <- list()
-
-  #Start intra loop here
-  errors <- NULL
-  if(track==TRUE) pb <- utils::txtProgressBar(min = 0, max = n.intra, style = 3)
-  counter = 1
-  
-  for (i in 1:n.intra) {
-    ##Set response and predictor variables
-    #Vy is not provided or is not numeric, do not pick random value
-    if(!inherits(full.data[,resp], c("numeric","integer")) || is.null(Vy)) 
-    {full.data$respV <- stats::model.frame(formula, data = full.data)[,1]}
+intra_samp_phylm <-
+  function(formula,
+           data,
+           phy,
+           n.sim = 10,
+           n.intra = 3,
+           breaks = seq(.1, .5, .1),
+           model = "lambda",
+           Vy = NULL,
+           Vx = NULL,
+           distrib = "normal",
+           y.transf = NULL,
+           x.transf = NULL,
+           track = TRUE,
+           ...) {
+    #Error check
+    if (is.null(Vx) & is.null(Vy))
+      stop("Vx or Vy must be defined")
+    if (!inherits(formula, "formula"))
+      stop("formula must be class 'formula'")
+    if (!inherits(data, "data.frame"))
+      stop("data must be class 'data.frame'")
+    if (!inherits(phy, "phylo"))
+      stop("phy must be class 'phylo'")
+    if (formula[[2]] != all.vars(formula)[1] ||
+        formula[[3]] != all.vars(formula)[2])
+      stop("Please use arguments y.transf or x.transf for data transformation")
+    if (distrib == "normal")
+      warning ("distrib=normal: make sure that standard deviation is provided for Vx and/or Vy")
+    if (length(breaks) < 2)
+      stop("Please include more than one break, e.g. breaks=c(.3,.5)")
+    if ((model == "trend") && (sum(is.ultrametric(phy)) > 1))
+      stop("Trend is unidentifiable for ultrametric trees., see ?phylolm for details")
+    else
+      
+      
+      #Matching tree and phylogeny using utils.R
+      datphy <- match_dataphy(formula, data, phy, ...)
+    full.data <- datphy[[1]]
+    phy <- datphy[[2]]
     
-    #choose a random value in [mean-se,mean+se] if Vy is provided
-    if (!is.null(Vy))
-    {full.data$respV <- apply(full.data[,c(resp,Vy)],1,function(x)funr(x[1],x[2]))}
+    resp <- all.vars(formula)[1]
+    pred <- all.vars(formula)[2]
     
-    #Vx is not provided or is not numeric, do not pick random value
-    if (!inherits(full.data[,pred], c("numeric","integer")) || is.null(Vx))
-    {full.data$predV <- stats::model.frame(formula, data = full.data)[,2]}
+    if (!is.null(Vy) && sum(is.na(full.data[, Vy])) != 0) {
+      full.data[is.na(full.data[, Vy]), Vy] <- 0
+    }
     
-    #choose a random value in [mean-se,mean+se] if Vx is provided
-    if(!is.null(Vx))
-    {full.data$predV <- apply(full.data[,c(pred,Vx)],1,function(x)funr(x[1],x[2]))}
+    if (!is.null(Vx) && sum(is.na(full.data[, Vx])) != 0) {
+      full.data[is.na(full.data[, Vx]), Vx] <- 0
+    }
     
-    #transform Vy and/or Vx if x.transf and/or y.transf are provided
-    if(!is.null(y.transf)) 
-    {suppressWarnings (full.data$respV <- y.transf(full.data$respV))}
+    #Function to pick a random value in the interval
+    if (distrib == "normal")
+      funr <- function(a, b) {
+        stats::rnorm(1, a, b)
+      }
+    else
+      funr <- function(a, b) {
+        stats::runif(1, a - b, a + b)
+      }
     
-    if(!is.null(x.transf)) 
-    {suppressWarnings (full.data$predV <- x.transf(full.data$predV))}
+    #List to store information
+    intra.samp <- list()
+    species.NA <- list()
     
-    #skip iteration if there are NA's in the dataset
-    species.NA[[i]]<-rownames(full.data[with(full.data,is.na(predV) | is.na(respV)),])
-    if(sum(is.na(full.data[,c("respV","predV")])>0)) next
+    #Start intra loop here
+    errors <- NULL
+    if (track == TRUE)
+      pb <- utils::txtProgressBar(min = 0, max = n.intra, style = 3)
+    counter = 1
     
-    #Run the model
-    intra.samp[[i]] <- samp_phylm(respV~predV, data = full.data, phy=phy, n.sim = n.sim,
-                                    model, breaks=breaks, track = FALSE, verbose = FALSE,...)
-
-    if(track==TRUE) utils::setTxtProgressBar(pb, counter)
-    counter = counter + 1
+    for (i in 1:n.intra) {
+      ##Set response and predictor variables
+      #Vy is not provided or is not numeric, do not pick random value
+      if (!inherits(full.data[, resp], c("numeric", "integer")) ||
+          is.null(Vy))
+      {
+        full.data$respV <-
+          stats::model.frame(formula, data = full.data)[, 1]
+      }
+      
+      #choose a random value in [mean-se,mean+se] if Vy is provided
+      if (!is.null(Vy))
+      {
+        full.data$respV <-
+          apply(full.data[, c(resp, Vy)], 1, function(x)
+            funr(x[1], x[2]))
+      }
+      
+      #Vx is not provided or is not numeric, do not pick random value
+      if (!inherits(full.data[, pred], c("numeric", "integer")) ||
+          is.null(Vx))
+      {
+        full.data$predV <-
+          stats::model.frame(formula, data = full.data)[, 2]
+      }
+      
+      #choose a random value in [mean-se,mean+se] if Vx is provided
+      if (!is.null(Vx))
+      {
+        full.data$predV <-
+          apply(full.data[, c(pred, Vx)], 1, function(x)
+            funr(x[1], x[2]))
+      }
+      
+      #transform Vy and/or Vx if x.transf and/or y.transf are provided
+      if (!is.null(y.transf))
+      {
+        suppressWarnings (full.data$respV <- y.transf(full.data$respV))
+      }
+      
+      if (!is.null(x.transf))
+      {
+        suppressWarnings (full.data$predV <- x.transf(full.data$predV))
+      }
+      
+      #skip iteration if there are NA's in the dataset
+      species.NA[[i]] <-
+        rownames(full.data[with(full.data, is.na(predV) | is.na(respV)), ])
+      if (sum(is.na(full.data[, c("respV", "predV")]) > 0))
+        next
+      
+      #Run the model
+      intra.samp[[i]] <-
+        samp_phylm(
+          respV ~ predV,
+          data = full.data,
+          phy = phy,
+          n.sim = n.sim,
+          model,
+          breaks = breaks,
+          track = FALSE,
+          verbose = FALSE,
+          ...
+        )
+      
+      if (track == TRUE)
+        utils::setTxtProgressBar(pb, counter)
+      counter = counter + 1
+    }
+    
+    if (track == TRUE)
+      close(pb)
+    names(intra.samp) <- 1:n.intra
+    
+    # Merge lists into data.frames between iterations:
+    full.estimates  <-
+      suppressWarnings(recombine(intra.samp, slot1 = 4, slot2 = 1))
+    influ.estimates <- recombine(intra.samp, slot1 = 5)
+    influ.estimates$info <- NULL
+    perc.sign <- recombine(intra.samp, slot1 = 6)
+    perc.sign$info <- NULL
+    
+    
+    #Generates output:
+    res <- list(
+      call = match.call(),
+      model = model,
+      formula = formula,
+      full.model.estimates = full.estimates,
+      sensi.estimates = influ.estimates,
+      sign.analysis = perc.sign,
+      data = full.data
+    )
+    
+    
+    class(res) <- "sensiIntra_Samp"
+    ### Warnings:
+    if (length(res$errors) > 0) {
+      warning("Some species deletion presented errors, please check: output$errors")
+    }
+    else {
+      res$errors <- "No errors found."
+    }
+    return(res)
   }
   
-  if(track==TRUE) close(pb)
-  names(intra.samp)<-1:n.intra
-  
-  # Merge lists into data.frames between iterations:
-  full.estimates  <- suppressWarnings(recombine(intra.samp, slot1 = 4, slot2 = 1))
-  influ.estimates <- recombine(intra.samp, slot1 = 5)
-  influ.estimates$info <- NULL
-  perc.sign <- recombine(intra.samp, slot1 = 6)
-  perc.sign$info <- NULL
-  
-  
-  #Generates output:
-  res <- list(call = match.call(),
-              model = model,
-              formula = formula,
-              full.model.estimates = full.estimates,
-              sensi.estimates = influ.estimates,
-              sign.analysis = perc.sign,
-              data = full.data)
-  
-  
-  class(res) <- "sensiIntra_Samp"
-  ### Warnings:
-  if (length(res$errors) >0){
-    warning("Some species deletion presented errors, please check: output$errors")}
-  else {
-    res$errors <- "No errors found."
-  }
-  return(res)
-}
-  
   
\ No newline at end of file
