@@ -37,6 +37,13 @@
 #' @author Caterina Penone & Pablo Ariel Martinez
 #' @seealso \code{\link[phylolm]{phyloglm}}, \code{\link{sensi_plot}},\code{\link{tree_phylm}}
 #' @references 
+#' 
+#' Paterno, G. B., Penone, C. Werner, G. D. A. 
+#' \href{http://doi.wiley.com/10.1111/2041-210X.12990}{sensiPhy: 
+#' An r-package for sensitivity analysis in phylogenetic 
+#' comparative methods.} Methods in Ecology and Evolution 
+#' 2018, 9(6):1461-1467
+#'
 #' Donoghue, M.J. & Ackerly, D.D. (1996). Phylogenetic Uncertainties and 
 #' Sensitivity Analyses in Comparative Biology. Philosophical Transactions:
 #'  Biological Sciences, pp. 1241-1249.
@@ -59,89 +66,139 @@
 #'sensi_plot(tree)
 #' @export
 
-tree_phyglm <- function(formula,data,phy,
-                         n.tree=2,btol=50,track=TRUE,...){
-
+tree_phyglm <- function(formula,
+                        data,
+                        phy,
+                        n.tree = 2,
+                        btol = 50,
+                        track = TRUE,
+                        ...) {
   #Error check
-  if(class(formula)!="formula") stop("formula must be class 'formula'")
-  if(class(data)!="data.frame") stop("data must be class 'data.frame'")
-  if(class(phy)!="multiPhylo") stop("phy must be class 'multiPhylo'")
-  if(length(phy)<n.tree) stop("'n.tree' must be smaller (or equal) than the number of trees in the 'multiPhylo' object")
+  if (!inherits(formula, "formula"))
+    stop("formula must be class 'formula'")
+  if (!inherits(data, "data.frame"))
+    stop("data must be class 'data.frame'")
+  if (!inherits(phy, "multiPhylo"))
+    stop("phy must be class 'multiPhylo'")
+  if (length(phy) < n.tree)
+    stop("'n.tree' must be smaller (or equal) than the number of trees in the 'multiPhylo' object")
   else
     
     #Matching tree and phylogeny using utils.R
-    datphy<-match_dataphy(formula,data,phy,...)
-  full.data<-datphy[[1]]
-  phy<-datphy[[2]]
+    datphy <- match_dataphy(formula, data, phy, ...)
+  full.data <- datphy[[1]]
+  phy <- datphy[[2]]
   
   # If the class of tree is multiphylo pick n=n.tree random trees
-  trees<-sample(length(phy),n.tree,replace=F)
+  trees <- sample(length(phy), n.tree, replace = F)
   
   #Create the results data.frame
-  sensi.estimates<-data.frame("n.tree"=numeric(),"intercept"=numeric(),"se.intercept"=numeric(),
-                                   "pval.intercept"=numeric(),"estimate"=numeric(),"se.estimate"=numeric(),
-                                   "pval.estimate"=numeric(),"aic"=numeric(),"optpar"=numeric())
+  sensi.estimates <-
+    data.frame(
+      "n.tree" = numeric(),
+      "intercept" = numeric(),
+      "se.intercept" = numeric(),
+      "pval.intercept" = numeric(),
+      "estimate" = numeric(),
+      "se.estimate" = numeric(),
+      "pval.estimate" = numeric(),
+      "aic" = numeric(),
+      "optpar" = numeric()
+    )
   
   #Model calculation
-  counter=1
+  counter = 1
   errors <- NULL
-  c.data<-list()
-  if(track==TRUE) pb <- utils::txtProgressBar(min = 0, max = n.tree, style = 3)
-  for (j in trees){
-    
+  c.data <- list()
+  if (track == TRUE)
+    pb <- utils::txtProgressBar(min = 0, max = n.tree, style = 3)
+  for (j in trees) {
     #Match data order to tip order
-    full.data <- full.data[phy[[j]]$tip.label,]
+    full.data <- full.data[phy[[j]]$tip.label, ]
     
     #phyloglm model
-    mod = try(phylolm::phyloglm(formula, data=full.data,phy=phy[[j]],method="logistic_MPLE",btol=btol),FALSE)
-
-    if(isTRUE(class(mod)=="try-error")) {
+    mod = try(phylolm::phyloglm(
+      formula,
+      data = full.data,
+      phy = phy[[j]],
+      method = "logistic_MPLE",
+      btol = btol
+    ),
+    FALSE)
+    
+    if (isTRUE(class(mod) == "try-error")) {
       error <- j
       names(error) <- rownames(c.data$full.data)[j]
-      errors <- c(errors,error)
-      next }
+      errors <- c(errors, error)
+      next
+    }
     
     
     else{
-      intercept            <- phylolm::summary.phyloglm(mod)$coefficients[[1,1]]
-      se.intercept         <- phylolm::summary.phyloglm(mod)$coefficients[[1,2]]
-      estimate             <- phylolm::summary.phyloglm(mod)$coefficients[[2,1]]
-      se.estimate          <- phylolm::summary.phyloglm(mod)$coefficients[[2,2]]
-      pval.intercept       <- phylolm::summary.phyloglm(mod)$coefficients[[1,4]]
-      pval.estimate        <- phylolm::summary.phyloglm(mod)$coefficients[[2,4]]
+      intercept            <-
+        phylolm::summary.phyloglm(mod)$coefficients[[1, 1]]
+      se.intercept         <-
+        phylolm::summary.phyloglm(mod)$coefficients[[1, 2]]
+      estimate             <-
+        phylolm::summary.phyloglm(mod)$coefficients[[2, 1]]
+      se.estimate          <-
+        phylolm::summary.phyloglm(mod)$coefficients[[2, 2]]
+      pval.intercept       <-
+        phylolm::summary.phyloglm(mod)$coefficients[[1, 4]]
+      pval.estimate        <-
+        phylolm::summary.phyloglm(mod)$coefficients[[2, 4]]
       aic.mod              <- mod$aic
       n                    <- mod$n
       #d                   <- mod$d
       optpar               <- mod$alpha
-
-      if(track==TRUE) utils::setTxtProgressBar(pb, counter)
+      
+      if (track == TRUE)
+        utils::setTxtProgressBar(pb, counter)
       
       #write in a table
-      estim.simu <- data.frame(j, intercept, se.intercept, pval.intercept,
-                               estimate, se.estimate, pval.estimate, aic.mod, optpar,
-                               stringsAsFactors = F)
-      sensi.estimates[counter, ]  <- estim.simu
-      counter=counter+1
+      estim.simu <-
+        data.frame(
+          j,
+          intercept,
+          se.intercept,
+          pval.intercept,
+          estimate,
+          se.estimate,
+          pval.estimate,
+          aic.mod,
+          optpar,
+          stringsAsFactors = F
+        )
+      sensi.estimates[counter,]  <- estim.simu
+      counter = counter + 1
       
     }
   }
-  if(track==TRUE) on.exit(close(pb))
+  if (track == TRUE)
+    on.exit(close(pb))
   #calculate mean and sd for each parameter
   #variation due to tree choice
-  statresults<-data.frame(min=apply(sensi.estimates,2,min),
-                          max=apply(sensi.estimates,2,max),
-                          mean=apply(sensi.estimates,2,mean),
-                          sd_tree=apply(sensi.estimates,2,stats::sd))[-1, ]
+  statresults <- data.frame(
+    min = apply(sensi.estimates, 2, min),
+    max = apply(sensi.estimates, 2, max),
+    mean = apply(sensi.estimates, 2, mean),
+    sd_tree = apply(sensi.estimates, 2, stats::sd)
+  )[-1,]
   
-  statresults$CI_low  <- statresults$mean - qt(0.975, df = n.tree-1) * statresults$sd_tree / sqrt(n.tree)
-  statresults$CI_high <- statresults$mean + qt(0.975, df = n.tree-1) * statresults$sd_tree / sqrt(n.tree)
+  statresults$CI_low  <-
+    statresults$mean - qt(0.975, df = n.tree - 1) * statresults$sd_tree / sqrt(n.tree)
+  statresults$CI_high <-
+    statresults$mean + qt(0.975, df = n.tree - 1) * statresults$sd_tree / sqrt(n.tree)
   
-  res <- list(call = match.call(),
-              formula=formula,
-              data=full.data,
-              sensi.estimates=sensi.estimates,N.obs=n,
-              stats = round(statresults[c(1:6),c(3,5,6)],digits=3),
-              all.stats = statresults)
-  class(res) <- c("sensiTree","sensiTreeL")
+  res <- list(
+    call = match.call(),
+    formula = formula,
+    data = full.data,
+    sensi.estimates = sensi.estimates,
+    N.obs = n,
+    stats = round(statresults[c(1:6), c(3, 5, 6)], digits = 3),
+    all.stats = statresults
+  )
+  class(res) <- c("sensiTree", "sensiTreeL")
   return(res)
 }
